[Lldb-commits] [PATCH] D12750: Link NetBSD with execinfo (CMAKE build)

Kamil Rytarowski via lldb-commits lldb-commits at lists.llvm.org
Wed Sep 9 18:56:35 PDT 2015


krytarowski created this revision.
krytarowski added a reviewer: joerg.
krytarowski added a subscriber: lldb-commits.
krytarowski set the repository for this revision to rL LLVM.

FreeBSD and NetBSD share the same library execinfo.

Repository:
  rL LLVM

http://reviews.llvm.org/D12750

Files:
  cmake/LLDBDependencies.cmake

Index: cmake/LLDBDependencies.cmake
===================================================================
--- cmake/LLDBDependencies.cmake
+++ cmake/LLDBDependencies.cmake
@@ -148,8 +148,8 @@
     list(APPEND LLDB_SYSTEM_LIBS panel ncurses)
   endif()
 endif()
-# On FreeBSD backtrace() is provided by libexecinfo, not libc.
-if (CMAKE_SYSTEM_NAME MATCHES "FreeBSD")
+# On FreeBSD/NetBSD backtrace() is provided by libexecinfo, not libc.
+if (CMAKE_SYSTEM_NAME MATCHES "FreeBSD" OR MAKE_SYSTEM_NAME MATCHES "NetBSD")
   list(APPEND LLDB_SYSTEM_LIBS execinfo)
 endif()
 


-------------- next part --------------
A non-text attachment was scrubbed...
Name: D12750.34401.patch
Type: text/x-patch
Size: 568 bytes
Desc: not available
URL: <http://lists.llvm.org/pipermail/lldb-commits/attachments/20150910/cdc2d7fd/attachment.bin>


More information about the lldb-commits mailing list